@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2020 Deepin Technology Co., Ltd.
- *
- * Author:     sunkang <sunkang@uniontech.com>
- *
- * Maintainer: sunkang <sunkang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QHBoxLayout>
 #include <QVBoxLayout>
@@ -959,10 +942,10 @@ DSearchComboBoxExample::DSearchComboBoxExample(QWidget *parent)
     pHBoxLayout_1->setSpacing(0);
 
     DSearchComboBox *pComboBox_1 = new DSearchComboBox(this);
-    pComboBox_1->setEditable(true);
-    pComboBox_1->addItem("手动选择驱动方案");
-    pComboBox_1->addItem("手动选择驱动方案");
-    pComboBox_1->addItem("手动选择驱动方案");
+    pComboBox_1->setEditable(false);
+    for (int i = 0; i < 16; ++i) {
+        pComboBox_1->addItem(QString("手动选择驱动方案%1").arg(i + 1));
+    }
     pComboBox_1->setFixedSize(240, 36);
     pHBoxLayout_1->addWidget(pComboBox_1);
 
