@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "darrowrectangle.h"
 #include "dplatformwindowhandle.h"
@@ -22,7 +9,7 @@
 #include "dstyle.h"
 
 #include <DGuiApplicationHelper>
-
+#include<qpa/qplatformnativeinterface.h>
 #ifdef Q_OS_LINUX
 #include <X11/extensions/shape.h>
 #include <QX11Info>
@@ -33,6 +20,10 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
+static bool isDwayland()
+{
+    return qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+}
 /*!
   \class Dtk::Widget::DArrowRectangle
   \inmodule dtkwidget
@@ -485,7 +476,8 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 
     d->m_backgroundColor = backgroundColor;
 
-    if (d->m_handle && d->m_backgroundColor.toRgb().alpha() < 255) {
+    bool isFloatWindow = d->floatMode == FloatWindow;
+    if ((d->m_handle || (isFloatWindow && isDwayland())) && d->m_backgroundColor.toRgb().alpha() < 255) {
         if (!d->m_blurBackground) {
             d->m_blurBackground = new DBlurEffectWidget(this);
             d->m_blurBackground->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
@@ -1134,6 +1126,9 @@ void DArrowRectanglePrivate::updateClipPath()
 {
     D_Q(DArrowRectangle);
 
+    if (!isDwayland() && !m_handle)
+        return;
+
     QPainterPath path;
 
     switch (m_arrowDirection) {
@@ -1155,7 +1150,7 @@ void DArrowRectanglePrivate::updateClipPath()
 
     if (m_handle) {
         m_handle->setClipPath(path);
-    } else {
+    } else if (DArrowRectangle::FloatWindow == floatMode && isDwayland()) {
         // clipPath without handle
         QPainterPathStroker stroker;
         stroker.setCapStyle(Qt::RoundCap);
@@ -1166,12 +1161,16 @@ void DArrowRectanglePrivate::updateClipPath()
 
         q->clearMask();
         q->setMask(polygon);
+        if (m_blurBackground)
+            m_blurBackground->setMaskPath(path);
 
         if (QWidget *widget = q->window()) {
             if (QWindow *w = widget->windowHandle()) {
                 QList<QPainterPath> painterPaths;
-                painterPaths << outPath;
-                w->setProperty("_d_windowBlurPaths", QVariant::fromValue(painterPaths));
+                painterPaths << outPath.united(path);
+                // 背景模糊也要设置一个 path
+                qApp->platformNativeInterface()->setWindowProperty(w->handle(), "_d_windowBlurPaths",
+                                                                   QVariant::fromValue(painterPaths));
             }
         }
     }
@@ -1238,8 +1237,17 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
             q->update();
             this->updateClipPath();
         }, Qt::QueuedConnection);
+    } else if (DArrowRectangle::FloatWidget == floatMode) {
+        DGraphicsGlowEffect *glowEffect = new DGraphicsGlowEffect;
+        glowEffect->setBlurRadius(q->shadowBlurRadius());
+        glowEffect->setDistance(m_shadowDistance);
+        glowEffect->setXOffset(q->shadowXOffset());
+        glowEffect->setYOffset(q->shadowYOffset());
+        q->setGraphicsEffect(glowEffect);
     } else {
-        m_wmHelper = nullptr;
+#ifndef QT_DEBUG
+        qDebug() << "wayland:" << isDwayland() << "floatMode:" << floatMode;
+#endif
     }
 }
 
