@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsearchedit.h"
 #include "dpalette.h"
@@ -169,19 +156,20 @@ private:
 #endif
 
 /*!
- * \~chinese \class DSearchEdit
- * \~chinese \brief DSearchEdit 类提供了专门用来进行搜索的输入框控件。
- * \~chinese
- * \~chinese 相比于一般的输入框控件，DSearchEdit 提供了搜索按钮指示，用户使用起来会更加自然。
- * \~chinese 如图示：
- * \~chinese \image html searchedit.png
- * \~chinese
- * \~chinese \warning DSearchEdit 与 QLineEdit、DLineEdit 没有继承关系，功能不兼容。
+  \class Dtk::Widget::DSearchEdit
+  \inmodule dtkwidget
+  \brief DSearchEdit 类提供了专门用来进行搜索的输入框控件.
+  
+  相比于一般的输入框控件，DSearchEdit 提供了搜索按钮指示，用户使用起来会更加自然。
+  如图示：
+  \image html searchedit.png
+  
+  \warning DSearchEdit 与 QLineEdit、DLineEdit 没有继承关系，功能不兼容。
  */
 
 /*!
- * \~chinese \brief DSearchEdit::DSearchEdit 是 DSearchEdit 类的构造函数。
- * \~chinese \param parent 指定了控件的父控件。
+  \brief DSearchEdit::DSearchEdit 是 DSearchEdit 类的构造函数.
+  \a parent 指定了控件的父控件。
  */
 DSearchEdit::DSearchEdit(QWidget *parent)
     : DLineEdit(*new DSearchEditPrivate(this), parent)
@@ -203,8 +191,8 @@ DSearchEdit::~DSearchEdit()
 }
 
 /*!
- * \~chinese \brief DSearchEdit::setPlaceHolder 设置灰色的占位符文本
- * \~chinese \param placeHolder 占位符文本内容
+  \brief DSearchEdit::setPlaceHolder 设置灰色的占位符文本
+  \a placeHolder 占位符文本内容
  */
 void DSearchEdit::setPlaceHolder(QString placeHolder)
 {
@@ -216,8 +204,8 @@ void DSearchEdit::setPlaceHolder(QString placeHolder)
 }
 
 /*!
- * \~chinese \brief DSearchEdit::placeHolder
- * \~chinese \return 返回占位符文本内容
+  \brief DSearchEdit::placeHolder
+  \return 返回占位符文本内容
  */
 QString DSearchEdit::placeHolder() const
 {
@@ -231,9 +219,8 @@ void DSearchEdit::clear()
     lineEdit()->clear();
 }
 
-
 /*!
- * \~chinese \brief DSearchEdit::clearEdit 清除内容，退出编辑状态
+  \brief DSearchEdit::clearEdit 清除内容，退出编辑状态
  */
 void DSearchEdit::clearEdit()
 {
@@ -251,7 +238,9 @@ bool DSearchEdit::isVoiceInput() const
 {
 #ifndef DTK_NO_MULTIMEDIA
     D_DC(DSearchEdit);
+#ifdef ENABLE_AI
     return d->voiceInput && d->voiceInput->state() == QAudio::ActiveState;
+#endif // 
 #else
     return false;
 #endif
@@ -332,6 +321,7 @@ void DSearchEditPrivate::init()
 
     center_layout->addWidget(iconbtn, 0, Qt::AlignVCenter);
     center_layout->addWidget(label, 0, Qt::AlignCenter);
+    center_layout->addSpacing(12 / qApp->devicePixelRatio());
     layout->addWidget(iconWidget, 0, Qt::AlignCenter);
 
     QAction* clearAction = q->lineEdit()->findChild<QAction *>(QLatin1String("_q_qlineeditclearaction"));
