@@ -1,25 +1,6 @@
-/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
- * -*- coding: utf-8 -*-
- *
- * Copyright (C) 2011 ~ 2017 Deepin, Inc.
- *               2011 ~ 2017 Wang Yong
- *
- * Author:     Wang Yong <wangyong@deepin.com>
- * Maintainer: Wang Yong <wangyong@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsimplelistview.h"
 #include <DObjectPrivate>
@@ -96,9 +77,13 @@ public:
 };
 
 /*!
- * \~chinese \class DSimpleListView
- * \~chinese \brief DSimpleListView 是 deepin 基于 QWidget 从零绘制的列表控件。
- * \~chinese \brief 开发者只要懂得怎么使用 QPainter 进行图形绘制，开发者就可以在 DSimpleListItem 中绘制任意行内容，包括文本、图片、任意控件甚至每行都可以画一个小电影，而代码的复杂度不会随着绘制行内容而发生变化，所有的行内容都源于怎么使用 QPainter。
+  \class Dtk::Widget::DSimpleListView
+  \inmodule dtkwidget
+  \brief DSimpleListView 是 deepin 基于 QWidget 从零绘制的列表控件.
+
+  开发者只要懂得怎么使用 QPainter 进行图形绘制，开发者就可以在 DSimpleListItem 中绘制任意行内容，
+  包括文本、图片、任意控件甚至每行都可以画一个小电影，而代码的复杂度不会随着绘制行内容而发生变化，
+  所有的行内容都源于怎么使用 QPainter.
  */
 
 DSimpleListView::DSimpleListView(QWidget *parent) : QWidget(parent), DObject(*new DSimpleListViewPrivate(this))
@@ -189,7 +174,9 @@ DSimpleListView::~DSimpleListView()
 }
 
 /*!
- * \~chinese \brief 设置行高
+  \brief 设置行高.
+
+  \a height 行高.
  */
 void DSimpleListView::setRowHeight(int height)
 {
@@ -200,7 +187,9 @@ void DSimpleListView::setRowHeight(int height)
 }
 
 /*!
- * \~chinese \brief 设置列标题信息
+  \brief 设置列标题信息
+
+  \a titles 标题列表， \a widths 宽度列表, \a height 高度.
  */
 void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> widths, int height)
 {
@@ -230,9 +219,9 @@ void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> width
 }
 
 /*!
- * \~chinese \brief 设置列隐藏标志
- * \~chinese \param toggleHideFlags 用于控制列的隐藏标志，用于切换显示/隐藏。
- * \~chinese \param visibleColumnIndex 列始终可见的列索引，默认值为 -1，表示列始终不可见。
+  \brief 设置列隐藏标志
+  \a toggleHideFlags 用于控制列的隐藏标志，用于切换显示/隐藏。
+  \a visibleColumnIndex 列始终可见的列索引，默认值为 -1，表示列始终不可见。
  */
 void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibleColumnIndex)
 {
@@ -250,7 +239,9 @@ void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibl
 }
 
 /*!
- * \~chinese \brief 设置列排序算法
+  \brief 设置列排序算法.
+
+  \a algorithms 列排序算法 , \a sortColumn 排序的列项 , \a descendingSort 是否为降序排序.
  */
 void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithms, int sortColumn, bool descendingSort)
 {
@@ -269,7 +260,9 @@ void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithm
 }
 
 /*!
- * \~chinese \brief 设置搜索算法
+  \brief 设置搜索算法.
+
+  \a algorithm 搜索算法.
  */
 void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
 {
@@ -279,7 +272,9 @@ void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
 }
 
 /*!
- * \~chinese \brief 设置圆角半径
+  \brief 设置圆角半径.
+
+  \a radius 圆角大小.
  */
 void DSimpleListView::setClipRadius(int radius)
 {
@@ -289,10 +284,11 @@ void DSimpleListView::setClipRadius(int radius)
 }
 
 /*!
- * \~chinese \brief 设置边角细节
- * \~chinese \param enableFrame 是否绘制边角
- * \~chinese \param color 边角颜色
- * \~chinese \param opacity 不透明度
+  \brief 设置边角细节.
+
+  \a enableFrame 是否绘制边角
+  \a color 边角颜色
+  \a opacity 不透明度
  */
 void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
 {
@@ -304,7 +300,9 @@ void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
 }
 
 /*!
- * \~chinese \brief 添加 DSimpleListItem 列表到视图中
+  \brief 添加 DSimpleListItem 列表到视图中.
+
+  \a items 视图项列表.
  */
 void DSimpleListView::addItems(QList<DSimpleListItem*> items)
 {
@@ -325,7 +323,9 @@ void DSimpleListView::addItems(QList<DSimpleListItem*> items)
 }
 
 /*!
- * \~chinese \brief 删除一个列表项
+  \brief 删除一个列表项.
+
+  \a item 列表项指针.
  */
 void DSimpleListView::removeItem(DSimpleListItem* item)
 {
@@ -342,7 +342,7 @@ void DSimpleListView::removeItem(DSimpleListItem* item)
 }
 
 /*!
- * \~chinese \brief 删除所有列表项
+  \brief 删除所有列表项
  */
 void DSimpleListView::clearItems()
 {
@@ -356,8 +356,9 @@ void DSimpleListView::clearItems()
 }
 
 /*!
- * \~chinese \brief 添加 DSimpleListItem 列表以在视图中选择效果
- * \~chinese \param recordLastSelection 为 true 则清除最后一个选择项
+  \brief 添加 DSimpleListItem 列表以在视图中选择效果
+  \a recordLastSelection 为 true 则清除最后一个选择项
+  \a items 列表项.
  */
 void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLastSelection)
 {
@@ -373,7 +374,9 @@ void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLa
 }
 
 /*!
- * \~chinese \brief 移除所有选择项
+  \brief 移除所有选择项.
+
+  \a clearLastSelection 是否清除最后选中的列表项.
  */
 void DSimpleListView::clearSelections(bool clearLastSelection)
 {
@@ -388,7 +391,9 @@ void DSimpleListView::clearSelections(bool clearLastSelection)
 }
 
 /*!
- * \~chinese \brief 获取所有选择项
+  \brief 获取所有选择项.
+
+  \return 返回选中的列表项.
  */
 QList<DSimpleListItem*> DSimpleListView::getSelections()
 {
@@ -398,7 +403,9 @@ QList<DSimpleListItem*> DSimpleListView::getSelections()
 }
 
 /*!
- * \~chinese \brief 刷新所有项
+  \brief 刷新所有项.
+
+  \a items 列表项.
  */
 void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
 {
@@ -463,7 +470,9 @@ void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
 }
 
 /*!
- * \~chinese \brief 搜索
+  \brief 搜索.
+
+  \a content 被搜索内容.
  */
 void DSimpleListView::search(QString content)
 {
@@ -486,7 +495,9 @@ void DSimpleListView::search(QString content)
 }
 
 /*!
- * \~chinese \brief 设置单一选择
+  \brief 设置单一选择.
+
+  \a singleSelect 是否单一选择.
  */
 void DSimpleListView::setSingleSelect(bool singleSelect)
 {
@@ -496,7 +507,9 @@ void DSimpleListView::setSingleSelect(bool singleSelect)
 }
 
 /*!
- * \~chinese \brief 单击空白区域时保持选择项
+  \brief 单击空白区域时保持选择项.
+
+  \a keep 是否保持选中项.
  */
 void DSimpleListView::keepSelectWhenClickBlank(bool keep)
 {
@@ -506,7 +519,7 @@ void DSimpleListView::keepSelectWhenClickBlank(bool keep)
 }
 
 /*!
- * \~chinese \brief 选择所有列表项
+  \brief 选择所有列表项.
  */
 void DSimpleListView::selectAllItems()
 {
@@ -530,7 +543,7 @@ void DSimpleListView::selectAllItems()
 }
 
 /*!
- * \~chinese \brief 选择第一项
+  \brief 选择第一项.
  */
 void DSimpleListView::selectFirstItem()
 {
@@ -554,7 +567,7 @@ void DSimpleListView::selectFirstItem()
 }
 
 /*!
- * \~chinese \brief 选择最后一项
+  \brief 选择最后一项.
  */
 void DSimpleListView::selectLastItem()
 {
@@ -578,7 +591,7 @@ void DSimpleListView::selectLastItem()
 }
 
 /*!
- * \~chinese \brief 移动到上一项
+  \brief 移动到上一项.
  */
 void DSimpleListView::selectPrevItem()
 {
@@ -586,7 +599,7 @@ void DSimpleListView::selectPrevItem()
 }
 
 /*!
- * \~chinese \brief 移动到下一项
+  \brief 移动到下一项.
  */
 void DSimpleListView::selectNextItem()
 {
@@ -594,7 +607,7 @@ void DSimpleListView::selectNextItem()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到下一页的项
+  \brief 从当前项选择到下一页的项.
  */
 void DSimpleListView::shiftSelectPageDown()
 {
@@ -606,7 +619,7 @@ void DSimpleListView::shiftSelectPageDown()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到上一页的项
+  \brief 从当前项选择到上一页的项.
  */
 void DSimpleListView::shiftSelectPageUp()
 {
@@ -618,7 +631,7 @@ void DSimpleListView::shiftSelectPageUp()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到末尾项
+  \brief 从当前项选择到末尾项.
  */
 void DSimpleListView::shiftSelectToEnd()
 {
@@ -646,7 +659,7 @@ void DSimpleListView::shiftSelectToEnd()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到起始项
+  \brief 从当前项选择到起始项.
  */
 void DSimpleListView::shiftSelectToHome()
 {
@@ -674,7 +687,7 @@ void DSimpleListView::shiftSelectToHome()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到下一项
+  \brief 从当前项选择到下一项.
  */
 void DSimpleListView::shiftSelectToNext()
 {
@@ -686,7 +699,7 @@ void DSimpleListView::shiftSelectToNext()
 }
 
 /*!
- * \~chinese \brief 从当前项选择到上一项
+  \brief 从当前项选择到上一项.
  */
 void DSimpleListView::shiftSelectToPrev()
 {
@@ -698,7 +711,7 @@ void DSimpleListView::shiftSelectToPrev()
 }
 
 /*!
- * \~chinese \brief 滚动到下一页
+  \brief 滚动到下一页.
  */
 void DSimpleListView::scrollPageDown()
 {
@@ -708,7 +721,7 @@ void DSimpleListView::scrollPageDown()
 }
 
 /*!
- * \~chinese \brief 滚动到上一页
+  \brief 滚动到上一页.
  */
 void DSimpleListView::scrollPageUp()
 {
