@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     wp <wangpeng_cm@deepin.com>
- *
- * Maintainer: wp <wangpeng_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dslider.h"
 #include "private/dslider_p.h"
@@ -62,31 +45,51 @@ private:
 };
 
 /*!
- * \~chinese \class DSlider
- * \~chinese \brief DSlider一个聚合 QSlider 的滑块
- * \~chinese \row \li DSlider提供了在滑块两侧设置图标函数
- * \~chinese \row \li DSlider提供了滑块的刻度及刻度标识
+  \class Dtk::Widget::DSlider
+  \inmodule dtkwidget
+  \brief DSlider一个聚合 QSlider 的滑块.
+
+  DSlider提供了在滑块两侧设置图标函数
+  DSlider提供了滑块的刻度及刻度标识
  */
 
 /*!
- * \~chinese \fn DSlider::valueChanged
- * \~chinese \brief 信号会在 slider value 属性的值改变时被发送
- * \~chinese \fn DSlider::sliderMoved
- * \~chinese \brief 信号会在 slider 拖动时被发送
- * \~chinese \fn DSlider::sliderReleased
- * \~chinese \brief 信号会在 slider被松开时被发送
- * \~chinese \fn DSlider::rangeChanged
- * \~chinese \brief 信号会在 range 属性的值改变时被发送
- * \~chinese \fn DSlider::actionTriggered
- * \~chinese \brief 信号会在 slider actoin 触发时被发送
- * \~chinese \fn DSlider::iconClicked
- * \~chinese \brief 信号会在左右 iconbutton 被点击时被发送
+  \fn void DSlider::valueChanged(int value)
+  \brief 信号会在 slider \a value 属性的值改变时被发送.
+ */
+/*!
+  \fn void DSlider::sliderMoved(int position)
+  \brief 信号会在 slider 拖动时被发送.
+
+  \a position 为 slider 被拖动的指针的位置。
+ */
+/*!
+  \fn void DSlider::sliderReleased()
+  \brief 信号会在 slider 被松开时被发送.
+ */
+/*!
+  \fn void DSlider::rangeChanged(int min, int max)
+  \brief 信号会在 range 属性的值改变时被发送.
+
+  \a min 为 range 的最小值， \a max 为 range 的最大值。
+ */
+/*!
+  \fn void DSlider::actionTriggered(int action)
+  \brief 信号会在 slider \a action 触发时被发送
+ */
+/*!
+  \fn void DSlider::iconClicked(SliderIcons icon, bool checked)
+  \brief 信号会在左右 iconbutton 被点击时被发送.
+
+  \a icon 表示按钮被点击的位置，\a checked 表示按钮是否被选中。
  */
 
 /*!
- * \~chinese \brief DSlider的构造函数
- * \~chinese \param \sa orientation Qt::Orientation
- * \~chinese \param parent参数被发送到 QWidget 构造函数。
+  \brief DSlider的构造函数.
+
+  \a parent 参数被发送到 QWidget 构造函数。
+
+  \sa Qt::Orientation
  */
 DSlider::DSlider(Qt::Orientation orientation, QWidget *parent)
     : QWidget(parent)
@@ -114,8 +117,11 @@ bool DSlider::event(QEvent *e)
 }
 
 /*!
- * \~chinese \brief DSlider::eventFilter
- * \~chinese \row 此函数处理了鼠标滚轮事件
+  \brief 事件过滤器函数.
+  \reimp
+
+  此函数目前仅处理了鼠标滚轮事件
+  \a watched 被监听的子控件，\a e 对应的事件指针。
  */
 bool DSlider::eventFilter(QObject *watched, QEvent *e)
 {
@@ -128,8 +134,11 @@ bool DSlider::eventFilter(QObject *watched, QEvent *e)
 }
 
 /*!
- * \~chinese \brief DSlider::orientation
- * \~chinese \sa QSlider::orientation()
+  \brief 滑块方向
+
+  \return 返回当前滑块的方向。
+
+  \sa QSlider::orientation()
  */
 Qt::Orientation DSlider::orientation() const
 {
@@ -137,9 +146,10 @@ Qt::Orientation DSlider::orientation() const
     return d->slider->orientation();
 }
 /*!
- * \~chinese \brief DSlider::slider返回 QSlider 对象
- * \~chinese \row 若 DSlider 不满足输入框的使用需求，请用此函数抛出的对象
- * \~chinese \return
+  \brief 返回 QSlider 对象.
+
+  若 DSlider 不满足输入框的使用需求，请用此函数抛出的对象。
+  \return QSlider 对象。
  */
 QSlider *DSlider::slider()
 {
@@ -148,8 +158,8 @@ QSlider *DSlider::slider()
 }
 
 /*!
- * \~chinese \brief DSlider::setLeftIcon设置滑块左侧图标
- * \~chinese \param left图标
+  \brief 设置滑块左侧图标.
+  \a left 左图标
  */
 void DSlider::setLeftIcon(const QIcon &left)
 {
@@ -176,8 +186,8 @@ void DSlider::setLeftIcon(const QIcon &left)
 }
 
 /*!
- * \~chinese \brief DSlider::setRightIcon设置滑块右图标
- * \~chinese \param right图标
+  \brief 设置滑块右图标.
+  \a right 右图标
  */
 void DSlider::setRightIcon(const QIcon &right)
 {
@@ -203,8 +213,8 @@ void DSlider::setRightIcon(const QIcon &right)
 }
 
 /*!
- * \~chinese \brief DSlider::setIconSize设置滑块图标大小
- * \~chinese \param size图标大小
+  \brief 设置滑块图标大小.
+  \a size 图标大小
  */
 void DSlider::setIconSize(const QSize &size)
 {
@@ -222,8 +232,11 @@ void DSlider::setIconSize(const QSize &size)
 }
 
 /*!
- * \~chinese \brief DSlider::setMinimum
- * \~chinese \sa QSlider::setMinimum()
+  \brief 设置滑动范围的最小值.
+
+  \a min 滑动最小值。
+
+  \sa QSlider::setMinimum() DSlider::minimum()
  */
 void DSlider::setMinimum(int min)
 {
@@ -232,8 +245,11 @@ void DSlider::setMinimum(int min)
 }
 
 /*!
- * \~chinese \brief DSlider::minimum
- * \~chinese \sa QSlider::minimum()
+  \brief 滑动范围的最小值.
+
+  \return 返回滑动范围的最小值。
+
+  \sa QSlider::minimum() DSlider::setMinimum()
  */
 int DSlider::minimum() const
 {
@@ -242,8 +258,11 @@ int DSlider::minimum() const
 }
 
 /*!
- * \~chinese \brief DSlider::setValue
- * \~chinese \sa QSlider::setValue()
+  \brief 设置滑块当前值
+
+  \a value 滑块的当前值。
+
+  \sa QSlider::setValue()
  */
 void DSlider::setValue(int value)
 {
@@ -252,8 +271,8 @@ void DSlider::setValue(int value)
 }
 
 /*!
- * \~chinese \brief DSlider::value
- * \~chinese \sa QSlider::value()
+  \brief DSlider::value
+  \sa QSlider::value()
  */
 int DSlider::value() const
 {
@@ -262,8 +281,14 @@ int DSlider::value() const
 }
 
 /*!
- * \~chinese \brief DSlider::setPageStep
- * \~chinese \sa QSlider::setPageStep()
+  \brief 设置页面单步的大小
+
+  使用按键 PageUp 或者 PageDown 时，滑块
+  滑动的单步大小。
+
+  \a pageStep 单步大小.
+
+  \sa QSlider::setPageStep()
  */
 void DSlider::setPageStep(int pageStep)
 {
@@ -272,8 +297,11 @@ void DSlider::setPageStep(int pageStep)
 }
 
 /*!
- * \~chinese \brief DSlider::pageStep
- * \~chinese \sa QSlider::pageStep()
+  \brief 返回页面单步大小
+
+  \return 页面单步大小的值。
+
+  \sa QSlider::pageStep() DSlider::setPageStep()
  */
 int DSlider::pageStep() const
 {
@@ -282,8 +310,11 @@ int DSlider::pageStep() const
 }
 
 /*!
- * \~chinese \brief DSlider::setMaximum
- * \~chinese \sa QSlider::setMaximum()
+  \brief 设置滑动范围的最大值
+
+  \a max 滑动范围的最大值。
+
+  \sa QSlider::setMaximum() DSlider::maximum()
  */
 void DSlider::setMaximum(int max)
 {
@@ -292,8 +323,11 @@ void DSlider::setMaximum(int max)
 }
 
 /*!
- * \~chinese \brief DSlider::maximum
- * \~chinese \sa QSlider::maximum
+  \brief 返回滑动范围的最大值
+
+  \return 滑动范围的最大值
+
+  \sa QSlider::maximum
  */
 int DSlider::maximum() const
 {
@@ -302,11 +336,12 @@ int DSlider::maximum() const
 }
 
 /*!
- * \~chinese \brief DSlider::setLeftTicks设置刻度在滑块左侧
- * \~chinese \row 根据 QStringList 数量，绘制刻度的个数，绘制刻度标识
- * \~chinese \row \li 滑块为水平,刻度在滑块上方
- * \~chinese \row \li 滑块为垂直,刻度在滑块左侧
- * \~chinese \param info刻度标识
+  \brief 设置滑块左侧的刻度值.
+
+  根据 QStringList 数量，绘制刻度的个数，绘制刻度标识：
+  滑块为水平,刻度在滑块上方；滑块为垂直,刻度在滑块左侧。
+
+  \a info 刻度标识
  */
 void DSlider::setLeftTicks(const QStringList &info)
 {
@@ -337,11 +372,12 @@ void DSlider::setLeftTicks(const QStringList &info)
 }
 
 /*!
- * \~chinese \brief DSlider::setRightTicks设置刻度在滑块右侧
- * \~chinese \row 根据 QStringList 数量，绘制刻度的个数，绘制刻度标识
- * \~chinese \row \li 滑块为水平,刻度在滑块下方
- * \~chinese \row \li 滑块为垂直,刻度在滑块右侧
- * \~chinese \param info刻度标识
+  \brief 设置滑块右侧的刻度值.
+
+  根据 QStringList 数量，绘制刻度的个数，绘制刻度标识：
+  滑块为水平,刻度在滑块下方；滑块为垂直,刻度在滑块右侧。
+
+  \a info 刻度标识
  */
 void DSlider::setRightTicks(const QStringList &info)
 {
@@ -372,8 +408,11 @@ void DSlider::setRightTicks(const QStringList &info)
 }
 
 /*!
- * \~chinese \brief DSlider::setAboveTicks设置刻度在滑块上方
- * \~chinese \sa DSlider::setLeftTicks()
+  \brief 设置滑块上方的刻度值
+
+  \a info 刻度标识.
+
+  \sa DSlider::setLeftTicks()
  */
 void DSlider::setAboveTicks(const QStringList &info)
 {
@@ -381,8 +420,11 @@ void DSlider::setAboveTicks(const QStringList &info)
 }
 
 /*!
- * \~chinese \brief DSlider::setBelowTicks设置刻度在滑块下方
- * \~chinese \sa DSlider::setRightTicks()
+  \brief 设置滑块下方的刻度值
+
+  \a info 刻度标识.
+
+  \sa DSlider::setRightTicks()
  */
 void DSlider::setBelowTicks(const QStringList &info)
 {
@@ -390,25 +432,28 @@ void DSlider::setBelowTicks(const QStringList &info)
 }
 
 /*!
- * \~chinese \brief DSlider::setMarkPositions 设置显示双边的刻度线（不显示刻度值）
- * \~chinese \li 举例用途：比如调节音量的 DSlider，需要在 value = 100 的地方标记一个刻度，而不需要显示其他的刻度值（并且实际音量值是可以超过 100 的）
- * \~chinese \li 其他：设置指定数值的刻度线(setMarkPositions)和设置刻度线+刻度值(setBelowTicks)是两个相互独立的，且互不干扰，若是同时使用，也会同时绘画各自的线；
- * \~chinese         另外两个的先后顺序也并没有关系
- *
- * \~chinese \code 示例代码
- * \~chinese \row DSlider* slider = new DSlider(Qt::Horizontal, wTemp);
- * \~chinese \row QStringList list1;
- * \~chinese \row list1<<"0"<<"25"<<"50"<<"75"<<"100";
- * \~chinese \row slider->setBelowTicks(list1);
- * \~chinese \row QStringList list2;
- * \~chinese \row list2<<"0"<<"25"<<"50"<<"75"<<"100"";
- * \~chinese \row slider->setAboveTicks(list2);
- * \~chinese \row QList<int> list3;
- * \~chinese \row list3<<0<<30<<80;
- * \~chinese \row slider->setMarkPositions(list3);
- * \~chinese \row slider->setMinimum(0);
- * \~chinese \row slider->setMaximum(100);
- * \~chinese \endcode
+  \brief 设置显示双边的刻度线（不显示刻度值）.
+
+  举例用途：比如调节音量的 DSlider ，需要在 value = 100 的地方标记一个刻度，而不需要显示其他的刻度值（并且实际音量值是可以超过 100 的）
+  其他：设置指定数值的刻度线(setMarkPositions)和设置刻度线+刻度值(setBelowTicks)是两个相互独立的，且互不干扰，若是同时使用，也会同时绘画各自的线；
+  另外两个的先后顺序也并没有关系.
+
+  \a list 双边刻度线的值.
+  
+  \code 示例代码
+  DSlider* slider = new DSlider(Qt::Horizontal, wTemp);
+  QStringList list1;
+  list1 << "0" << "25" << "50" << "75" << "100";
+  slider->setBelowTicks(list1);
+  QStringList list2;
+  list2 << "0" << "25" << "50" << "75" << "100"";
+  slider->setAboveTicks(list2);
+  QList<int> list3;
+  list3 << 0 << 30 << 80;
+  slider->setMarkPositions(list3);
+  slider->setMinimum(0);
+  slider->setMaximum(100);
+  \endcode
  */
 void DSlider::setMarkPositions(QList<int> list)
 {
@@ -457,8 +502,11 @@ void DSlider::setMarkPositions(QList<int> list)
 }
 
 /*!
- * \~chinese \brief DSlider::setMouseWheelEnabled设置鼠标滚轮是否开启
- * \~chinese \param enabled是否开启鼠标滚轮
+  \brief 设置鼠标滚轮是否开启.
+
+  开启鼠标滚轮后，用户可以通过鼠标滚轮来控制滑块的滑动。
+
+  \a enabled 是否开启鼠标滚轮
  */
 void DSlider::setMouseWheelEnabled(bool enabled)
 {
@@ -505,8 +553,9 @@ void DSliderPrivate::updtateTool(int value)
 }
 
 /*!
- * \~chinese \brief DSlider::setTipValue 此函数会创建气泡，气泡将跟随滑块移动
- * \~chinese \param open value非空开启气泡 value空关闭气泡(销毁)
+  \brief 用于创建气泡，气泡将跟随滑块移动.
+
+  \a value 非空开启气泡 \a value 空关闭气泡(销毁)
  */
 void DSlider::setTipValue(const QString &value)
 {
@@ -536,10 +585,12 @@ void DSlider::setTipValue(const QString &value)
 }
 
 /*!
- * \~chinese \brief DSlider::tickPosition返回滑块的记号位置
- * \~chinese \row 获取滑块刻度当前朝向
- * \~chinese \row \sa QSlider::TickPosition
- * \~chinese \return
+  \brief 返回滑块的记号位置.
+
+  获取滑块刻度当前朝向。
+
+  \return 滑块刻度的朝向
+  \sa QSlider::TickPosition
  */
 QSlider::TickPosition DSlider::tickPosition() const
 {
@@ -561,8 +612,13 @@ QSlider::TickPosition DSlider::tickPosition() const
 }
 
 /*!
- * \~chinese \brief DSlider::sizeHint
- * \~chinese \sa  QSlider::sizeHint
+  \brief 滑动条的大小策略
+
+  这个函数会返回该滑动条推荐的大小，如果
+  滑动条没有布局，这个大小将会是一个无效值，如果
+  存在布局，将返回该布局下的推荐大小。
+
+  \sa  QSlider::sizeHint
  */
 QSize DSlider::sizeHint() const
 {
@@ -574,8 +630,10 @@ QSize DSlider::sizeHint() const
 }
 
 /*!
- * \~chinese \brief DSlider::setHandleVisible 设置滑块时候显示
- * \~chinese \param b 显示滑块的 bool 值
+  \brief 设置滑块是否显示.
+
+  \a b 为 true 时滑块显示，否则滑块隐藏。
+  默认地，滑块为显示状态。
  */
 void DSlider::setHandleVisible(bool b)
 {
@@ -589,8 +647,9 @@ void DSlider::setHandleVisible(bool b)
 }
 
 /*!
- * \~chinese \brief DSlider::handleVisible 获取滑块是否显示的状态
- * \~chinese \return 返回滑块是否显示的状态
+  \brief 获取滑块是否显示的状态.
+
+  \return 返回滑块是否显示的状态
  */
 bool DSlider::handleVisible() const
 {
@@ -599,9 +658,11 @@ bool DSlider::handleVisible() const
 }
 
 /*!
- * \~chinese \brief DSlider::setEnabledAcrossStyle 滑槽是否禁用活动色填充已经滑过的滑槽
- * \~chinese 默认普通 DSlider 滑过的滑槽是活动色填充， 调用过 setXXXTicks 的 DSlider 则默认禁用活动色填充
- * \~chinese \param enabled true 无活动色，可用于音量平衡等不需要显示滑过的，false 滑过的位置(如左侧)是高亮色显示，如调节亮度等(默认)
+  \brief 该函数用于设置滑槽是否禁用活动色填充已经滑过的滑槽.
+
+  默认普通 DSlider 滑过的滑槽是活动色填充， 调用过 setXXXTicks 的 DSlider 则默认禁用活动色填充
+  \a enabled true 无活动色，可用于音量平衡等不需要显示滑过的，false 滑过的位置(如左侧)是高亮色显示，如调节亮度等(默认)
+  默认地，改属性为 false 。
  */
 void DSlider::setEnabledAcrossStyle(bool enabled)
 {
@@ -672,9 +733,10 @@ QSize SliderStrip::sizeHint() const
 }
 
 /*!
- * \~chines \brief SliderStrip::setScaleInfo 设置显示刻度线和刻度值
- * \~chines \param scaleInfo 显示的刻度值
- * \~chines \param tickPosition 显示的方向枚举值
+  \internal
+  \brief SliderStrip::setScaleInfo 设置显示刻度线和刻度值
+  \a scaleInfo 显示的刻度值
+  \a tickPosition 显示的方向枚举值
  */
 void SliderStrip::setScaleInfo(QStringList scaleInfo, QSlider::TickPosition tickPosition)
 {
@@ -683,9 +745,10 @@ void SliderStrip::setScaleInfo(QStringList scaleInfo, QSlider::TickPosition tick
 }
 
 /*!
- * \~chines \brief SliderStrip::setMarkList 设置显示刻度线（不显示刻度值）
- * \~chines \param list 显示的刻度线的list
- * \~chines \param tickPosition 显示的方向枚举值
+  \internal
+  \brief SliderStrip::setMarkList 设置显示刻度线（不显示刻度值）
+  \a list 显示的刻度线的list
+  \a tickPosition 显示的方向枚举值
  */
 void SliderStrip::setMarkList(QList<int> list, QSlider::TickPosition tickPosition)
 {
@@ -694,8 +757,9 @@ void SliderStrip::setMarkList(QList<int> list, QSlider::TickPosition tickPositio
 }
 
 /*!
- * \~chines \brief SliderStrip::getList 返回刻度线的 list
- * \~chines \return 刻度线的 list
+  \internal
+  \brief SliderStrip::getList 返回刻度线的 list
+  \return 刻度线的 list
  */
 QList<int> SliderStrip::getList()
 {
@@ -703,8 +767,9 @@ QList<int> SliderStrip::getList()
 }
 
 /*!
- * \~chines \brief SliderStrip::getScaleInfo 返回刻度值的 list
- * \~chines \return 度值的 list
+  \internal
+  \brief SliderStrip::getScaleInfo 返回刻度值的 list
+  \return 度值的 list
  */
 QStringList SliderStrip::getScaleInfo()
 {
@@ -712,8 +777,9 @@ QStringList SliderStrip::getScaleInfo()
 }
 
 /*!
- * \~chines \brief SliderStrip::paintEvent
- * \~chines \sa QWidget::paintEvent()
+  \internal
+  \brief SliderStrip::paintEvent
+  \sa QWidget::paintEvent()
  */
 void SliderStrip::paintEvent(QPaintEvent *event)
 {
@@ -836,8 +902,9 @@ void SliderStrip::paintEvent(QPaintEvent *event)
 }
 
 /*!
- * \~chines \brief SliderStrip::event
- * \~chines \sa QWidget::event()
+  \internal
+  \brief SliderStrip::event
+  \sa QWidget::event()
  */
 bool SliderStrip::event(QEvent *e)
 {
