@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dtabbar.h"
 #include "dobject_p.h"
 
@@ -242,12 +226,20 @@ public:
             ll = isRectType ? 6 : TabSpacing;
             lr = isRectType ? 6 : TabSpacing;
         }
+
+        /* 右箭头、添加按钮都显示，则右键投左右边距6，添加按钮左右边距10
+         * 右箭头、添加按钮都不显示，则没有边距
+         * 只显示右键，左右边距为6
+         * 只显示添加按钮，左右边距为10
+         */
         if (rightScrollButton->isVisible()) {
             rl = isRectType ? 6 : TabSpacing;
-            const int AddButtonLeftMargin = 8;
+            const int AddButtonLeftMargin = 6;
             al = AddButtonLeftMargin;
         }
         if (addButton->isVisible()) {
+            const int AddButtonLeftMargin = 10;
+            al = AddButtonLeftMargin;
             const int AddButtonRightMargin = 10;
             ar = AddButtonRightMargin;
         }
@@ -264,7 +256,6 @@ public:
             leftBtnR->changeSize(0, lr);
             rightBtnL->changeSize(0, rl);
             addBtnL->changeSize(0, al);
-            addBtnR->changeSize(0, al);
             addBtnR->changeSize(0, ar);
         }
         layout->invalidate();
@@ -1506,39 +1497,86 @@ QTabBarPrivate *DTabBarPrivate::dd() const
 }
 
 /*!
- * \~chinese \class DTabBar
- * \~chinese \brief DTabBar 是一个标签栏控件，是在 QTabBar 基础之上进行扩展增强。
- *
- * \~chinese 增加了许多特性，比如：新建按钮，支持向外拖放事件...该控件目前被深度编辑器中所使用。
+  \class Dtk::Widget::DTabBar
+  \inmodule dtkwidget
+  \brief DTabBar 是一个标签栏控件，是在 QTabBar 基础之上进行扩展增强.
+  
+  增加了许多特性，比如：新建按钮，支持向外拖放事件...该控件目前被深度编辑器中所使用。
  */
 
 /*!
- * \~chinese \fn DTabBar::currentChanged()
- * \~chinese \brief 当前索引位置改变
- * \~chinese \fn DTabBar::tabCloseRequested()
- * \~chinese \brief 点击关闭后发出
- * \~chinese \fn DTabBar::tabMoved()
- * \~chinese \brief 索引位置发生变化
- * \~chinese \fn DTabBar::tabIsInserted()
- * \~chinese \brief 新标签已插入
- * \~chinese \fn DTabBar::tabIsRemoved()
- * \~chinese \brief 标签已删除
- * \~chinese \fn DTabBar::tabBarClicked()
- * \~chinese \brief 点击索引标签
- * \~chinese \fn DTabBar::tabBarDoubleClicked()
- * \~chinese \brief 双击索引标签
- * \~chinese \fn DTabBar::tabAddRequested()
- * \~chinese \brief 新标签加入
- * \~chinese \fn DTabBar::tabReleaseRequested()
- * \~chinese \brief 索引标签鼠标释放
- * \~chinese \fn DTabBar::dragActionChanged()
- * \~chinese \brief 鼠标形状发生变化
- * \~chinese \fn DTabBar::tabDroped()
- * \~chinese \brief 标签拖放
- * \~chinese \fn DTabBar::dragStarted()
- * \~chinese \brief 开始拖起
- * \~chinese \fn DTabBar::dragEnd()
- * \~chinese \brief 拖放结束
+  \fn void DTabBar::currentChanged(int index)
+  \brief 当前索引位置改变.
+
+  \a index 改变的索引值.
+ */
+/*!
+  \fn void DTabBar::tabCloseRequested(int index)
+  \brief 点击关闭后发出.
+
+  \a index 关闭的索引值.
+ */
+/*!
+  \fn void DTabBar::tabMoved(int from, int to)
+  \brief 索引位置发生变化
+
+  \a from 索引位置变化的初始值， \a to 位置变化后的索引值.
+ */
+/*!
+  \fn void DTabBar::tabIsInserted(int index)
+  \brief 新标签已插入.
+
+  \a index 被插入标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabIsRemoved(int index)
+  \brief 标签已删除.
+
+  \a index 被删除标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabBarClicked(int index)
+  \brief 点击索引标签.
+
+  \a index 点击标签的索引值.
+ */
+/*!
+  \fn void DTabBar::tabBarDoubleClicked(int index)
+  \brief 双击索引标签.
+
+  \a index 双击标记的索引值.
+ */
+/*!
+  \fn void DTabBar::tabAddRequested()
+  \brief 新标签加入.
+ */
+/*!
+  \fn void DTabBar::tabReleaseRequested(int index)
+  \brief 索引标签鼠标释放.
+
+  \a index 标签释放的索引值.
+ */
+/*!
+  \fn void DTabBar::dragActionChanged(Qt::DropAction action)
+  \brief 鼠标形状发生变化.
+
+  \a action 改变的拖拽动作.
+ */
+/*!
+  \fn void DTabBar::tabDroped(int index, Qt::DropAction action, QObject *target)
+  \brief 标签拖放.
+
+  \a index 拖放的标签索引， \a action 拖放的动作, \a target 被拖放的标签 DTabBar 实例
+ */
+/*!
+  \fn void DTabBar::dragStarted()
+  \brief 开始拖起.
+ */
+/*!
+  \fn void DTabBar::dragEnd(Qt::DropAction action)
+  \brief 拖放结束.
+
+  \a action 拖放动作.
  */
 
 DTabBar::DTabBar(QWidget *parent)
@@ -1549,7 +1587,9 @@ DTabBar::DTabBar(QWidget *parent)
 }
 
 /*!
- * \~chinese \brief 设置索引标签的最小尺寸
+  \brief 设置索引标签的最小尺寸.
+
+  \a index 被设置标签的索引值，size ，\a size 最小大小.
  */
 void DTabBar::setTabMinimumSize(int index, const QSize &size)
 {
@@ -1566,7 +1606,9 @@ void DTabBar::setTabMinimumSize(int index, const QSize &size)
 }
 
 /*!
- * \~chinese \brief 设置索引标签的最大尺寸
+  \brief 设置索引标签的最大尺寸.
+
+  \a index 被设置标签的索引值，size ，\a size 最大大小.
  */
 void DTabBar::setTabMaximumSize(int index, const QSize &size)
 {
@@ -1583,7 +1625,9 @@ void DTabBar::setTabMaximumSize(int index, const QSize &size)
 }
 
 /*!
- * \~chinese \brief 新建标签栏按钮是否可见
+  \brief 新建标签栏按钮是否可见.
+
+  \return 新建按钮可见，返回 ture 否则，返回 false 。
  */
 bool DTabBar::visibleAddButton() const
 {
@@ -1593,7 +1637,9 @@ bool DTabBar::visibleAddButton() const
 }
 
 /*!
- * \~chinese \brief 标签栏形状
+  \brief 标签栏形状.
+
+  \return 返回当前 DTabBar 实例的标签栏形状.
  */
 QTabBar::Shape DTabBar::shape() const
 {
@@ -1601,7 +1647,9 @@ QTabBar::Shape DTabBar::shape() const
 }
 
 /*!
- * \~chinese \brief 设置标签栏形状
+  \brief 设置标签栏形状.
+
+  \a shape 标签栏形状.
  */
 void DTabBar::setShape(QTabBar::Shape shape)
 {
@@ -1630,7 +1678,10 @@ void DTabBar::setShape(QTabBar::Shape shape)
 }
 
 /*!
- * \~chinese \brief 添加一个新的标签，返回新标签的索引
+  \brief 添加一个新的标签，返回新标签的索引.
+
+  \a text 新标签的标题文本.
+  \return 返回新标签的索引.
  */
 int DTabBar::addTab(const QString &text)
 {
@@ -1638,7 +1689,10 @@ int DTabBar::addTab(const QString &text)
 }
 
 /*!
- * \~chinese \brief 添加一个新的标签，包含图标、文本
+  \brief 添加一个新的标签，包含图标、文本.
+
+  \a icon 新标签的标题图标， \a text 新标签的标题文本.
+  \return 返回新标签的索引.
  */
 int DTabBar::addTab(const QIcon &icon, const QString &text)
 {
@@ -1646,7 +1700,15 @@ int DTabBar::addTab(const QIcon &icon, const QString &text)
 }
 
 /*!
- * \~chinese \brief 插入一个文本标签
+  \brief 插入一个文本标签.
+
+  \a index 被插入的标签索引值， \a text 新标签的标题文本.
+
+  \warning 如果参数 \a index 超过了当前索引，将会在最后添加
+  一个新标签.
+
+  \return 返回插入后的新标签索引.
+  \sa QTabBar::insertTab()
  */
 int DTabBar::insertTab(int index, const QString &text)
 {
@@ -1654,7 +1716,11 @@ int DTabBar::insertTab(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 插入一个图标文本标签
+  \brief 插入一个图标文本标签.
+
+  \a index 被插入的标签索引值，\a icon 新标签的图标，\a text 新标签文本
+
+  \return 返回插入后的新标签索引.
  */
 int DTabBar::insertTab(int index, const QIcon &icon, const QString &text)
 {
@@ -1662,7 +1728,9 @@ int DTabBar::insertTab(int index, const QIcon &icon, const QString &text)
 }
 
 /*!
- * \~chinese \brief 移除标签索引位置
+  \brief 移除标签索引位置
+
+  \a index 被移除的标签索引值.
  */
 void DTabBar::removeTab(int index)
 {
@@ -1670,7 +1738,9 @@ void DTabBar::removeTab(int index)
 }
 
 /*!
- * \~chinese \brief 移动标签索引位置
+  \brief 移动标签索引位置
+
+  \a from 被移动前的标签索引，\a to 被移动后的标签索引.
  */
 void DTabBar::moveTab(int from, int to)
 {
@@ -1678,7 +1748,11 @@ void DTabBar::moveTab(int from, int to)
 }
 
 /*!
- * \~chinese \brief 是否启用标签索引位置
+  \brief 是否启用标签索引位置
+
+  \a index 标签索引值.
+
+  \return 启用标签索引返回 true，否则返回 false.
  */
 bool DTabBar::isTabEnabled(int index) const
 {
@@ -1686,7 +1760,9 @@ bool DTabBar::isTabEnabled(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置启用状态
+  \brief 设置标签索引位置启用状态
+
+  \a index 标签索引，\a enable 是否启用.
  */
 void DTabBar::setTabEnabled(int index, bool enable)
 {
@@ -1694,7 +1770,10 @@ void DTabBar::setTabEnabled(int index, bool enable)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置文本
+  \brief 返回标签索引位置文本.
+
+  \a index 标签索引.
+  \return 返回对应索引的文本.
  */
 QString DTabBar::tabText(int index) const
 {
@@ -1702,7 +1781,9 @@ QString DTabBar::tabText(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置文本
+  \brief 设置标签索引位置文本.
+
+  \a index 标签索引， \a text 标签文本.
  */
 void DTabBar::setTabText(int index, const QString &text)
 {
@@ -1710,7 +1791,10 @@ void DTabBar::setTabText(int index, const QString &text)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置图标
+  \brief 返回标签索引位置图标.
+
+  \a index 标签索引.
+  \return 对应标签的图标.
  */
 QIcon DTabBar::tabIcon(int index) const
 {
@@ -1718,7 +1802,9 @@ QIcon DTabBar::tabIcon(int index) const
 }
 
 /*!
- * \~chinese \brief 设置标签索引位置图标
+  \brief 设置标签索引位置图标.
+
+  \a index 标签索引， \a icon 对应的标签图标.
  */
 void DTabBar::setTabIcon(int index, const QIcon &icon)
 {
@@ -1726,7 +1812,9 @@ void DTabBar::setTabIcon(int index, const QIcon &icon)
 }
 
 /*!
- * \~chinese \brief 缩略模式
+  \brief 缩略模式.
+
+  \return 返回标签的文本缩略模式.
  */
 Qt::TextElideMode DTabBar::elideMode() const
 {
@@ -1734,7 +1822,9 @@ Qt::TextElideMode DTabBar::elideMode() const
 }
 
 /*!
- * \~chinese \brief 设置缩略模式
+  \brief 设置缩略模式
+
+  \a mode 文本缩略模式.
  */
 void DTabBar::setElideMode(Qt::TextElideMode mode)
 {
@@ -1744,7 +1834,9 @@ void DTabBar::setElideMode(Qt::TextElideMode mode)
 #ifndef QT_NO_TOOLTIP
 
 /*!
- * \~chinese \brief 设置标签索引位置提示文本
+  \brief 设置标签索引位置提示文本.
+
+  \a index 标签索引, \a tip 提示文本.
  */
 void DTabBar::setTabToolTip(int index, const QString &tip)
 {
@@ -1752,7 +1844,9 @@ void DTabBar::setTabToolTip(int index, const QString &tip)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置提示文本
+  \brief 返回标签索引位置提示文本.
+
+  \a index 标签索引.
  */
 QString DTabBar::tabToolTip(int index) const
 {
@@ -1773,7 +1867,9 @@ QString DTabBar::tabWhatsThis(int index) const
 #endif
 
 /*!
- * \~chinese \brief 设置标签索引位置数据
+  \brief 设置标签索引位置数据.
+
+  \a index 标签索引, \a data 标签数据.
  */
 void DTabBar::setTabData(int index, const QVariant &data)
 {
@@ -1781,7 +1877,10 @@ void DTabBar::setTabData(int index, const QVariant &data)
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置数据
+  \brief 返回标签索引位置数据.
+
+  \a index 标签索引.
+  \return 标签数据.
  */
 QVariant DTabBar::tabData(int index) const
 {
@@ -1789,7 +1888,10 @@ QVariant DTabBar::tabData(int index) const
 }
 
 /*!
- * \~chinese \brief 返回标签索引位置矩形
+  \brief 返回标签索引位置矩形.
+
+  \a index 标签索引.
+  \return 标签矩形.
  */
 QRect DTabBar::tabRect(int index) const
 {
@@ -1801,7 +1903,10 @@ QRect DTabBar::tabRect(int index) const
 }
 
 /*!
- * \~chinese \brief 根据位置返回标签索引位置
+  \brief 根据位置返回标签索引位置.
+
+  \a pos 对应标签坐标，可以时标签内的任意坐标.
+  \return 返回对应标签的索引值.
  */
 int DTabBar::tabAt(const QPoint &pos) const
 {
@@ -1809,7 +1914,9 @@ int DTabBar::tabAt(const QPoint &pos) const
 }
 
 /*!
- * \~chinese \brief 当前的标签索引位置
+  \brief 当前的标签索引位置.
+
+  \return 当前标签索引.
  */
 int DTabBar::currentIndex() const
 {
@@ -1817,7 +1924,9 @@ int DTabBar::currentIndex() const
 }
 
 /*!
- * \~chinese \brief 标签总数
+  \brief 标签总数.
+
+  \return 返回标签总数.
  */
 int DTabBar::count() const
 {
@@ -1835,7 +1944,9 @@ bool DTabBar::drawBase() const
 }
 
 /*!
- * \~chinese \brief 图标大小
+  \brief 图标大小.
+
+  \return 返回图标大小.
  */
 QSize DTabBar::iconSize() const
 {
@@ -1843,7 +1954,9 @@ QSize DTabBar::iconSize() const
 }
 
 /*!
- * \~chinese \brief 设置图标大小
+  \brief 设置图标大小.
+
+  \a size 图标大小.
  */
 void DTabBar::setIconSize(const QSize &size)
 {
@@ -1861,7 +1974,9 @@ void DTabBar::setUsesScrollButtons(bool useButtons)
 }
 
 /*!
- * \~chinese \brief 标签栏是否可关闭
+  \brief 标签栏是否可关闭.
+
+  \return 返回标签是否可关闭.
  */
 bool DTabBar::tabsClosable() const
 {
@@ -1869,7 +1984,9 @@ bool DTabBar::tabsClosable() const
 }
 
 /*!
- * \~chinese \brief 设置标签栏是否可关闭
+  \brief 设置标签栏是否可关闭.
+
+  \a closable 标签是否可关闭.
  */
 void DTabBar::setTabsClosable(bool closable)
 {
@@ -1998,9 +2115,11 @@ QWindow *DTabBar::dragIconWindow() const
 }
 
 /*!
- * \~chinese \brief DTabBar::setEnabledEmbedStyle 启用直角样式的Tabbar
- * \~chinese \row 此风格适用于切换窗口的操作,多用于支持多开的应用
- * \param replace true 启用，false 恢复
+  \brief 启用直角样式的 Tabbar.
+
+  此风格适用于切换窗口的操作,多用于支持多开的应用.
+
+  \a enable true 启用，false 恢复
  */
 void DTabBar::setEnabledEmbedStyle(bool enable)
 {
@@ -2028,8 +2147,9 @@ void DTabBar::setEnabledEmbedStyle(bool enable)
 }
 
 /*!
- * \~chinese \brief DTabBar::setTabLabelAlignment 设置tab标签文字对齐方式
- * \~chinese \param alignment 对齐
+  \brief 设置 tab 标签文字对齐方式.
+
+  \a alignment 对齐方式.
  */
 void DTabBar::setTabLabelAlignment(Qt::Alignment alignment)
 {
@@ -2037,7 +2157,9 @@ void DTabBar::setTabLabelAlignment(Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief 设置当前标签索引位置
+  \brief 设置当前标签索引位置.
+
+  \a index 标签索引.
  */
 void DTabBar::setCurrentIndex(int index)
 {
@@ -2045,7 +2167,9 @@ void DTabBar::setCurrentIndex(int index)
 }
 
 /*!
- * \~chinese \brief 设置新建标签按钮是否显示
+  \brief 设置新建标签按钮是否显示.
+
+  \a visibleAddButton 新建按钮是否可视.
  */
 void DTabBar::setVisibleAddButton(bool visibleAddButton)
 {
@@ -2056,7 +2180,9 @@ void DTabBar::setVisibleAddButton(bool visibleAddButton)
 }
 
 /*!
- * \~chinese \brief 设置开始拖动距离
+  \brief 设置开始拖动距离.
+
+  \a startDragDistance 开始拖动的距离.
  */
 void DTabBar::setStartDragDistance(int startDragDistance)
 {
@@ -2064,7 +2190,9 @@ void DTabBar::setStartDragDistance(int startDragDistance)
 }
 
 /*!
- * \~chinese \brief 设置颜色
+  \brief 设置颜色.
+
+  \a maskColor 遮罩颜色.
  */
 void DTabBar::setMaskColor(QColor maskColor)
 {
